@@ -1,11 +1,10 @@
 from simpleicons.icon import Icon
-icon= Icon(
+dynamics365_icon= Icon(
     title="Dynamics 365",
     slug="dynamics365",
     hex="002050",
     source="http://thepartnerchannel.com/wp-content/uploads/Dynamics365_styleguide_092816.pdf",
-    svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>Dynamics 365 icon</title><path d="M4.59 7.41l4.94 3.54L4.59 24zm0-7.41v6.36l9.53 5.29 4.59-3.52zm0 24l14.82-8.47v-6.7Z"/></svg>
-""",
+    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Dynamics 365</title><path d="M4.59 7.41l4.94 3.54L4.59 24zm0-7.41v6.36l9.53 5.29 4.59-3.52zm0 24l14.82-8.47v-6.7Z"/></svg>""",
     guidelines=None,
     license=None,
 )
