@@ -1,10 +1,10 @@
 from simpleicons.icon import Icon
-icon= Icon(
+lospec_icon= Icon(
     title="Lospec",
     slug="lospec",
     hex="EAEAEA",
     source="https://lospec.com/brand",
-    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Lospec icon</title><path d="M4.23 0v24h15.541v-8.4004h-7.1719v3.5996H11.402V0z"/></svg>""",
+    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Lospec</title><path d="M4.23 0v24h15.541v-8.4004h-7.1719v3.5996H11.402V0z"/></svg>""",
     guidelines='https://lospec.com/brand',
     license=None,
 )
